##  Evaluating the TBM Taxonomy: Key Considerations
To determine if the TBM Taxonomy suits your needs, consider the following questions:
  * Does the TBM Solutions layer meet your criteria for a standard tech category taxonomy?
  * How does your current taxonomy compare to the TBM Solutions layer?
  * Does your current taxonomy have more or fewer details than the TBM Solutions layer?
  * How would the mapping to your IT components change if you adopt the TBM Solutions layer?
  * Do you want to manage the assignment of tech categories to IT components, or would you prefer to do it automatically?


Your answers to these questions will guide your decision on whether to adopt the TBM Taxonomy, and if so, whether to adopt it fully or partially. Once you've decided on your tech category taxonomy, you can proceed to import the TBM Taxonomy and assign IT components to TBM-based tech categories.
